@@ -3,6 +3,21 @@
     configure -- configuration toolkit
     ==================================
 
+    This module provides wrapper around PyYAML with the following features:
+
+        * intepolation for string values
+
+        * configuration merging
+
+        * configuration inheritance (via 'extends' top-level attribute)
+
+    Basic usage is:
+
+        >>> from configure import Configuration
+        >>> c = Configuration.from_file("./example.conf")
+        >>> c.settings["a"]
+        2
+
 """
 
 from os import path
@@ -19,7 +34,13 @@ class ConfigurationError(ValueError):
     """ Configuration error"""
 
 class Configuration(MutableMapping):
-    """ Configuration object"""
+    """ Configuration
+
+    You should never instantiate this object but use ``from_file``,
+    ``from_string`` or ``from_dict`` classmethods instead.
+
+    Implements :class:`collections.MutableMapping` protocol.
+    """
 
     def __init__(self, struct=None, ctx=None):
         self.__struct = struct
@@ -73,12 +94,14 @@ class Configuration(MutableMapping):
         for k, v in config.items():
             if isinstance(v, Mapping) and k in self:
                 if not isinstance(self[k], Mapping):
-                    raise ConfigurationError("unresolveable conflict during merge")
+                    raise ConfigurationError(
+                        "unresolveable conflict during merge")
                 self[k]._merge(v)
             else:
                 self[k] = v
 
     def merge(self, config):
+        """ Merge configuration into this one"""
         new = self.__class__({})
         new._merge(self)
         new._merge(config)
@@ -88,8 +111,9 @@ class Configuration(MutableMapping):
         return self.merge(config)
 
     def configure(self, struct):
+        """ Configure with other configuration object"""
         if isinstance(struct, self.__class__):
-            struct = struct._Config__struct
+            struct = struct._Configuration__struct
         self.__struct = struct
 
     def __repr__(self):
@@ -99,6 +123,14 @@ class Configuration(MutableMapping):
 
     @classmethod
     def from_file(cls, filename, ctx=None):
+        """ Construct :class:`.Configuration` object by reading and parsing file
+        ``filename``.
+
+        :param filename:
+            filename to parse config from
+        :param ctx:
+            mapping object used for value interpolation
+        """
         with open(filename, "r") as f:
             cfg = cls(load(f.read()), ctx=ctx)
         if "extends" in cfg:
@@ -109,10 +141,24 @@ class Configuration(MutableMapping):
 
     @classmethod
     def from_string(cls, string, ctx=None):
+        """ Construct :class:`.Configuration` from ``string``.
+
+        :param string:
+            string to parse config from
+        :param ctx:
+            mapping object used for value interpolation
+        """
         return cls(load(string), ctx=ctx)
 
     @classmethod
     def from_dict(cls, d, ctx=None):
+        """ Construct :class:`.Configuration` from dict ``d``.
+
+        :param d:
+            mapping object to use for config
+        :param ctx:
+            mapping object used for value interpolation
+        """
         return cls(d, ctx=ctx)
 
 def _timedelta_contructor(loader, node):
